@@ -1,13 +1,13 @@
 package Language::Expr::EvaluatorRole;
-# ABSTRACT: Specification for Language::Expr interpreter/compiler
 
-our $VERSION = '0.23'; # VERSION
+our $DATE = '2016-06-16'; # DATE
+our $VERSION = '0.24'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
 
-use Moo::Role;
+use Role::Tiny;
 
 requires 'rule_pair_simple';
 requires 'rule_pair_string';
@@ -41,7 +41,6 @@ requires 'rule_parenthesis';
 requires 'expr_preprocess';
 requires 'expr_postprocess';
 
-
 sub parse_dquotestr {
     my ($self, @parts) = @_;
     if (ref($parts[0]) eq 'ARRAY') { splice @parts, 0, 1, @{ $parts[0] } }
@@ -91,7 +90,6 @@ sub parse_dquotestr {
     \@res;
 }
 
-
 sub parse_squotestr {
     my ($self, @parts) = @_;
     if (ref($parts[0]) eq 'ARRAY') { splice @parts, 0, 1, @{ $parts[0] } }
@@ -111,6 +109,7 @@ sub parse_squotestr {
 }
 
 1;
+# ABSTRACT: Specification for Language::Expr interpreter/compiler
 
 __END__
 
@@ -124,7 +123,7 @@ Language::Expr::EvaluatorRole - Specification for Language::Expr interpreter/com
 
 =head1 VERSION
 
-This document describes version 0.23 of module Language::Expr::EvaluatorRole (in distribution Language-Expr), released on 2014-05-01.
+This document describes version 0.24 of Language::Expr::EvaluatorRole (from Perl distribution Language-Expr), released on 2016-06-16.
 
 =head1 METHODS
 
@@ -157,7 +156,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Language-E
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Language-Expr>.
+Source repository is at L<https://github.com/perlancar/perl-Language-Expr>.
 
 =head1 BUGS
 
@@ -169,11 +168,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
