@@ -1,19 +1,23 @@
 package Language::Expr::Parser;
-# ABSTRACT: Parse Language::Expr expression
 
-our $VERSION = '0.23'; # VERSION
+our $DATE = '2016-06-16'; # DATE
+our $VERSION = '0.24'; # VERSION
 
-use 5.010;
+use 5.010001;
 # now can't compile with this on?
 #use strict;
 #use warnings;
 
+use Regexp::Grammars;
+
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(parse_expr);
 
 my $MAX_LEVELS = 3;
 
+# WARN: this is not thread-safe!?
+our $obj;
 
 sub parse_expr {
     my ($str, $obj_arg, $level) = @_;
@@ -21,10 +25,7 @@ sub parse_expr {
     $level //= 0;
     die "Recursion level ($level) too deep (max $MAX_LEVELS)" if $level >= $MAX_LEVELS;
 
-    use Regexp::Grammars;
-
     # WARN: this is not thread-safe!?
-    state $obj;
     local $subexpr_stack = [];
 
     # create not just 1 but 0..$MAX_LEVELS-1 of grammar objects, each
@@ -290,8 +291,8 @@ sub parse_expr {
     $obj_arg->expr_postprocess(result => $/{answer});
 }
 
-
 1;
+# ABSTRACT: Parse Language::Expr expression
 
 __END__
 
@@ -305,13 +306,7 @@ Language::Expr::Parser - Parse Language::Expr expression
 
 =head1 VERSION
 
-This document describes version 0.23 of module Language::Expr::Parser (in distribution Language-Expr), released on 2014-05-01.
-
-=head1 METHODS
-
-=head2 parse_expr($str, $obj)
-
-Parse expression in $str. Will call various rule_*() methods in $obj.
+This document describes version 0.24 of Language::Expr::Parser (from Perl distribution Language-Expr), released on 2016-06-16.
 
 =head1 KNOWN BUGS
 
@@ -321,13 +316,19 @@ Parse expression in $str. Will call various rule_*() methods in $obj.
 
 =back
 
+=head1 METHODS
+
+=head2 parse_expr($str, $obj)
+
+Parse expression in $str. Will call various rule_*() methods in $obj.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Language-Expr>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Language-Expr>.
+Source repository is at L<https://github.com/perlancar/perl-Language-Expr>.
 
 =head1 BUGS
 
@@ -339,11 +340,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
